USE [ChooseYourStory]
GO

/****** Object:  StoredProcedure [dbo].[Jobs_AwardTrophies]    Script Date: 2019-08-25 8:11:21 PM ******/
DROP PROCEDURE [dbo].[Jobs_AwardTrophies]
GO

/****** Object:  StoredProcedure [dbo].[Jobs_AwardTrophies]    Script Date: 2019-08-25 8:11:21 PM ******/
SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO


CREATE    PROCEDURE [dbo].[Jobs_AwardTrophies]
/********************************************************************************
 * ChooseYourStory >> Jobs >> Jobs_AwardTrophies
 ********************************************************************************
 * _author_
 * Alex Papadimoulis (alex@papadimoulis.com)
 *
 * _description_
 * awards trophies to members
 *
 * _history_
 * 20060602  AP  Created
 * 20060622  AP  Renamed Trophies table
 ********************************************************************************/
 AS BEGIN

BEGIN TRANSACTION

DELETE [User_Trophies]
 WHERE [Trophy_Name] IN
	 (SELECT [Trophy_Name] FROM [User_TrophyTypes]
     WHERE [Owner_Username] IS NULL
	 AND [Trophy_Name] <> 'Community Contributor' 
	 AND [Trophy_Name] <> 'Contest Winner')

IF @@ERROR<>0 BEGIN ROLLBACK RETURN END

/*******************************************************************************
 * Bugs Trophy
 *******************************************************************************/
INSERT INTO [User_Trophies] ([Username], [Trophy_Name], [Trophy_Notes])
SELECT TOP 5 P.[Username], 'Bug Hunter', 'Finding ' + CAST(COUNT([Username]) AS VARCHAR(10)) + ' Bugs'
  FROM [MyAdventuregame].dbo.[Forums_Posts] P
       INNER JOIN [MyAdventureGame].[dbo].[Forums_Bug_Resolutions] BR
               ON P.[Message_Id] = BR.[Message_Id]
 WHERE P.[Left] = 1
 GROUP BY P.[Username]
 ORDER BY COUNT(P.[Username]) DESC

/*******************************************************************************
 * Poster Trophy
 *******************************************************************************/
INSERT INTO [User_Trophies] ([Username], [Trophy_Name], [Trophy_Notes])
SELECT TOP 3 [Username], 'Supreme Poster', 'Posting ' + CAST(COUNT([Username]) AS VARCHAR(10)) + ' Forum Posts'
  FROM [MyAdventuregame].dbo.[Forums_Posts] FP
       JOIN [MyAdventureGame]..[Forums_Messages] FM ON FP.[Message_Id] = FM.[Message_Id]
 WHERE FM.[Forum_Id] <> 11
 GROUP BY [Username]
 ORDER BY COUNT([Username]) DESC

INSERT INTO [User_Trophies] ([Username], [Trophy_Name], [Trophy_Notes])
SELECT TOP 7 [Username], 'Top Poster', 'Posting ' + CAST(COUNT([Username]) AS VARCHAR(10)) + ' Forum Posts'
  FROM [MyAdventuregame].dbo.[Forums_Posts] FP
       JOIN [MyAdventureGame]..[Forums_Messages] FM ON FP.[Message_Id] = FM.[Message_Id]
 WHERE FM.[Forum_Id] <> 11
   AND [Username] NOT IN (SELECT [Username] FROM [User_Trophies] WHERE [Trophy_Name]='Supreme Poster')
 GROUP BY [Username]
 ORDER BY COUNT([Username]) DESC

/*******************************************************************************
 * Lucky Trophy
 *******************************************************************************/
INSERT INTO [User_Trophies] ([Username],[Trophy_Name],[Trophy_Notes])
SELECT TOP 1 PERCENT
       [Username], 'Lucky Dueler', 'Won ' +
         CONVERT( VARCHAR(3),
                  CEILING((SUM([Win])*1.0 / COUNT([Username])*100))
                 ) + '% of Duels'
  FROM (SELECT [Username] = [Challenger Username],
               [Win] = CASE WHEN [Winner] = 'Challenger' THEN 1 ELSE 0 END,
	             [Duel Date]
          FROM [MyAdventureGame].dbo.[Duels]
         WHERE [Winner] IN ('Challenger','Challengee')
        UNION ALL
        SELECT [Username] = [Challengee Username],
               [Win] = CASE WHEN [Winner] = 'Challengee' THEN 1 ELSE 0 END,
	             [Duel Date]
          FROM [MyAdventureGame].dbo.[Duels]
         WHERE [Winner] IN ('Challenger','Challengee')) X
 WHERE [Username] NOT IN ('Simpsons','Metsrock','Marmotlord','Ford','AngelOfThatThing','Charmeleon')
   AND EXISTS (SELECT * FROM [MyAdventureGame].dbo.[Duels]
                WHERE [Duel Date] > GETDATE() - 60
                  AND ([Challengee Username] = [Username] 
                       OR [Challenger Username] = [Username]))
 GROUP BY [Username]
 HAVING COUNT(*) >= 100
 ORDER BY (SUM([Win])*1.0 / COUNT([Username])*1.0) DESC
IF @@ERROR<>0 BEGIN ROLLBACK RETURN END

/*******************************************************************************
 * Top Rater
 *******************************************************************************/
INSERT INTO [User_Trophies] ([Username],[Trophy_Name],[Trophy_Notes])
SELECT R.[Username],
         CASE WHEN 95 <= (COUNT(*)*1.0) / (SELECT COUNT(*) FROM [MyAdventureGame].dbo.[Games - Published] WHERE R.[Username] <> [Username])*100.0
              THEN 'Supreme Rater'
              ELSE 'Top Rater' END,
         'Rated ' +
         CONVERT( VARCHAR(5),
                  CAST( (COUNT(*)*1.0) 
                             / (SELECT COUNT(*) FROM [MyAdventureGame].dbo.[Games - Published] 
                                 WHERE R.[Username] <> [Username])*100.0 AS DECIMAL(4,1))
                 ) + '% of all Stories'
  FROM [MyAdventureGame].dbo.[Games - Published] G
       INNER JOIN (SELECT DISTINCT [Game Id], [Username] FROM [MyAdventureGame].dbo.[Game Ratings]) R
               ON G.[Game Id] = R.[Game Id]
              AND G.[Username] <> R.[Username]
 GROUP BY R.[Username]
HAVING CEILING( (COUNT(*)*1.0) 
                  / (SELECT COUNT(*) FROM [MyAdventureGame].dbo.[Games - Published] 
                      WHERE R.[Username] <> [Username])*100.0) >= 50
IF @@ERROR<>0 BEGIN ROLLBACK RETURN END

/*******************************************************************************
 * Contest Winner (No longer required)

INSERT INTO [User_Trophies] ([Username],[Trophy_Name],[Trophy_Notes])
SELECT 'thatguy', 'Contest Winner', 'Won 2003 Make-A-Game Contest' UNION ALL
SELECT 'solostrike', 'Contest Winner', 'Won 2005 Make-A-Game Contest' UNION ALL
SELECT 'JJJ-thebanisher', 'Contest Winner', 'Won Feb 2006 Make-A-Game Contest, Won 2006 Contest: Runner Up' UNION ALL
SELECT 'madglee', 'Contest Winner', 'Won 2006 Contest: Best Overall, Won 2006 Contest: Best Use of Advanced Features' UNION ALL
SELECT 'tsmpaul', 'Contest Winner', 'Won 2006 Contest: Runner Up' UNION ALL
SELECT 'EndMaster', 'Contest Winner', 'Won 2007 Contest' UNION ALL
SELECT 'Steve24833', 'Contest Winner', 'Won 2016 Contest for new School-based Storygames' UNION ALL
SELECT 'Romulus', 'Contest Winner', 'Won 2016 Ballad Contest (traditional) and 2016 Mizal Short Story Contest' UNION ALL
SELECT 'WouldntItBeNice', 'Contest Winner', 'Jointly won the 2017 Wilderness Contest' UNION ALL
SELECT 'Ogre11', 'Contest Winner', 'Jointly won the 2017 Wilderness Contest' UNION ALL
SELECT 'TheNewIAP', 'Contest Winner', 'Won the 2018 Epic Contest' UNION ALL
SELECT 'EbonVasilis', 'Contest Winner', 'Won the 2018 Romance Contest' UNION ALL
SELECT 'AzBaz', 'Contest Winner', 'Won the 2017 Summer Slam Contest' UNION ALL
SELECT 'pugpup1', 'Contest Winner', 'Won 2016 Ballad Contest (overall) and 2019 Lone Hero Contest'
IF @@ERROR<>0 BEGIN ROLLBACK RETURN END
 *******************************************************************************/
/*******************************************************************************
 * Community Contributor (No longer required)
 
INSERT INTO [User_Trophies] ([Username],[Trophy_Name],[Trophy_Notes])
SELECT 'bradindvorak', 'Community Contributor', 'Profile Innovation and excellent advanced editor forum help' UNION ALL
SELECT 'bucky', 'Community Contributor', 'Running numerous contests.' UNION ALL
SELECT 'alexp', 'Community Contributor', 'Founding the website.' UNION ALL
SELECT 'march5th00', 'Community Contributor', 'Founding the website.' UNION ALL
SELECT 'chocobot', 'Community Contributor', 'Founding the website.' UNION ALL
SELECT 'Zikara', 'Community Contributor', 'Innovation in scripting.' UNION ALL
SELECT 'JJJ-thebanisher', 'Community Contributor', 'Administrative contributions, Continent, Commander, and programming.' UNION ALL
SELECT 'October', 'Community Contributor', 'Administrative contributions and Continent.' UNION ALL
SELECT 'BerkaZerka', 'Community Contributor', 'Administrative contributions.' UNION ALL
SELECT 'madglee', 'Community Contributor', 'Administrative contributions.' UNION ALL
SELECT 'fleshnblood_78', 'Community Contributor', 'Administrative contributions.' UNION ALL
SELECT 'EndMaster', 'Community Contributor', 'Administrative contributions and driving insane traffic our way.' UNION ALL
SELECT 'Killa_Robot', 'Community Contributor', 'Administrative contributions and great advanced editor forum help.' UNION ALL
SELECT 'mizal', 'Community Contributor', 'Thorough and consistent writing workshop contributions / excellent commenting.' UNION ALL
SELECT 'cysid', 'Community Contributor', 'General mascotting and dueling until blue in the face.' UNION ALL
SELECT 'Sethaniel', 'Community Contributor', 'Administrative contributions.' UNION ALL
SELECT 'Havacoman', 'Community Contributor', 'Administrative contributions and excellent work in the FWW & B&P.' UNION ALL
SELECT 'Will11', 'Community Contributor', 'The weekly review and a multitude of other minor contributions.' UNION ALL
SELECT 'Ogre11', 'Community Contributor', 'Genuinely inspiring advanced editor teaching and helping.' UNION ALL
SELECT 'deletedgames', 'Community Contributor', 'Deleting all of the games, man.'
IF @@ERROR<>0 BEGIN ROLLBACK RETURN END
*******************************************************************************/

/*******************************************************************************
 * Featured
 *******************************************************************************/
INSERT INTO [User_Trophies] ([Username],[Trophy_Name],[Trophy_Notes])
SELECT [Username], 'Featured Story', 'Having ' + CAST(COUNT(*) AS VARCHAR(3)) + ' Storygame(s) Featured'
  FROM [MyAdventureGame].dbo.[Games - Published]
 WHERE [Date Category Featured] IS NOT NULL
 GROUP BY [Username]
IF @@ERROR<>0 BEGIN ROLLBACK RETURN END

/*******************************************************************************
 * Points
 *******************************************************************************/
INSERT INTO [User_Trophies] ([Username],[Trophy_Name],[Trophy_Notes])
SELECT [Username], '100 Points', 'Earning 100 Points' FROM [MyAdventureGame].dbo.[Users]
 WHERE [Point Total] >= 100 AND [Username] NOT IN ('alexp','march5th00','chocobot', 'madglee', 'Endmaster', 'BerkaZerka', 'cysid')
UNION ALL
SELECT [Username], '500 Points', 'Earning 500 Points' FROM [MyAdventureGame].dbo.[Users]
 WHERE [Point Total] >= 500 AND [Username] NOT IN ('alexp','march5th00','chocobot', 'madglee', 'Endmaster', 'BerkaZerka', 'cysid')
UNION ALL
SELECT [Username], '1000 Points', 'Earning 1,000 Points' FROM [MyAdventureGame].dbo.[Users]
 WHERE [Point Total] >= 1000  AND [Username] NOT IN ('alexp','march5th00','chocobot', 'madglee', 'Endmaster', 'BerkaZerka', 'cysid')
UNION ALL
SELECT [Username], '2000 Points', 'Earning 2,000 Points' FROM [MyAdventureGame].dbo.[Users]
 WHERE [Point Total] >= 2000  AND [Username] NOT IN ('alexp','march5th00','chocobot', 'madglee', 'Endmaster', 'BerkaZerka', 'cysid')
UNION ALL
SELECT [Username], '5000 Points', 'Earning 5,000 Points' FROM [MyAdventureGame].dbo.[Users]
 WHERE [Point Total] >= 5000  AND [Username] NOT IN ('alexp','march5th00','chocobot', 'madglee', 'Endmaster', 'BerkaZerka', 'cysid')
UNION ALL
SELECT [Username], 'Infinite Points', 'Having Infinite Points' FROM [MyAdventureGame].dbo.[Users]
 WHERE [Username] IN ('alexp','march5th00','chocobot', 'madglee', 'Endmaster', 'BerkaZerka', 'cysid')
IF @@ERROR<>0 BEGIN ROLLBACK RETURN END

/*******************************************************************************
 * Endorsements
 *******************************************************************************/
UPDATE [MyAdventureGame].dbo.Users
SET [Sect Prefix] = '', [Sect Postfix] = '', [Endorsements_Yesterday] = ISNULL((SELECT SUM([Points]) FROM [MyAdventureGame].dbo.Endorsements WHERE [MyAdventureGame].dbo.Endorsements.[Username] = [MyAdventureGame].dbo.Users.Username AND [MyAdventureGame].dbo.Endorsements.[Endorsement_Date] > GETDATE() - 1),0)

UPDATE [MyAdventureGame].dbo.Users
SET [Sect Postfix] = ' Exemplar'
WHERE (SELECT MIN([MyAdventureGame].dbo.[Game Ratings - Calculated].Ranking_Overall) FROM [MyAdventureGame].dbo.[Game Ratings - Calculated] WHERE (SELECT [MyAdventureGame].dbo.Games.Username FROM [MyAdventureGame].dbo.Games WHERE [MyAdventureGame].dbo.Games.[Game Id] = [MyAdventureGame].dbo.[Game Ratings - Calculated].[Game ID]) = [MyAdventureGame].dbo.Users.Username and [MyAdventureGame].dbo.[Game Ratings - Calculated].Ranking_Overall > 0) <= 100

DECLARE @TOPENDORSER VARCHAR(20)
SET @TOPENDORSER = (SELECT TOP 1 [Username] FROM [MyAdventureGame].dbo.Users ORDER BY [MyAdventureGame].dbo.Users.[Endorsements_Yesterday] DESC, [MyAdventureGame].dbo.Users.[Point Total] DESC)

EXEC [MyAdventureGame].dbo.[Award Points]   
	@TransactionType = 'Admin. Bonus',
	@Username = @TOPENDORSER, 
	@Points = 10,
	@Notes = "Most Commended!"

UPDATE [MyAdventureGame].dbo.Users
SET [MyAdventureGame].dbo.Users.[Sect Postfix] = [MyAdventureGame].dbo.Users.[Sect Postfix] + ' of Avon' WHERE Username = @TOPENDORSER

DECLARE @SAGE_ENDORSEMENTS int
DECLARE @MARAUDER_ENDORSEMENTS int
DECLARE @ARCHITECT_ENDORSEMENTS int
DECLARE @WARDEN_ENDORSEMENTS int
DECLARE @MAX_ENDORSEMENTS int

SET @SAGE_ENDORSEMENTS = (SELECT SUM(u.[Endorsements_Yesterday]) FROM (SELECT [Endorsements_Yesterday] FROM [MyAdventureGame].dbo.Users WHERE [MyAdventureGame].dbo.Users.[Sect] = 'Sage') u) 
SET @MARAUDER_ENDORSEMENTS = (SELECT SUM(u.[Endorsements_Yesterday]) FROM (SELECT [Endorsements_Yesterday] FROM [MyAdventureGame].dbo.Users WHERE [MyAdventureGame].dbo.Users.[Sect] = 'Marauder') u) 
SET @ARCHITECT_ENDORSEMENTS = (SELECT SUM(u.[Endorsements_Yesterday]) FROM (SELECT [Endorsements_Yesterday] FROM [MyAdventureGame].dbo.Users WHERE [MyAdventureGame].dbo.Users.[Sect] = 'Architect') u) 
SET @WARDEN_ENDORSEMENTS = (SELECT SUM(u.[Endorsements_Yesterday]) FROM (SELECT [Endorsements_Yesterday] FROM [MyAdventureGame].dbo.Users WHERE [MyAdventureGame].dbo.Users.[Sect] = 'Warden') u) 
SET @MAX_ENDORSEMENTS = (SELECT MAX (v) from (SELECT @SAGE_ENDORSEMENTS as v UNION select @MARAUDER_ENDORSEMENTS as v UNION select @ARCHITECT_ENDORSEMENTS as v UNION select @WARDEN_ENDORSEMENTS as v) a)

UPDATE [MyAdventureGame].dbo.Users
SET [Sect First] = 'N'

If (@SAGE_ENDORSEMENTS = @MAX_ENDORSEMENTS)
BEGIN
UPDATE [MyAdventureGame].dbo.Users
SET [Sect First] = 'Y' WHERE [Sect] = 'Sage'
END

If (@MARAUDER_ENDORSEMENTS = @MAX_ENDORSEMENTS)
BEGIN
UPDATE [MyAdventureGame].dbo.Users
SET [Sect First] = 'Y' WHERE [Sect] = 'Marauder'
END

If (@ARCHITECT_ENDORSEMENTS = @MAX_ENDORSEMENTS)
BEGIN
UPDATE [MyAdventureGame].dbo.Users
SET [Sect First] = 'Y' WHERE [Sect] = 'Architect'
END

If (@WARDEN_ENDORSEMENTS = @MAX_ENDORSEMENTS)
BEGIN
UPDATE [MyAdventureGame].dbo.Users
SET [Sect First] = 'Y' WHERE [Sect] = 'Warden'
END

DECLARE @REQUIRED_MARAUDER5 int
DECLARE @REQUIRED_SAGE5 int
DECLARE @REQUIRED_ARCHITECT5 int
DECLARE @REQUIRED_WARDEN5 int
DECLARE @REQUIRED_MARAUDER1 int
DECLARE @REQUIRED_SAGE1 int
DECLARE @REQUIRED_ARCHITECT1 int
DECLARE @REQUIRED_WARDEN1 int
SET @REQUIRED_MARAUDER5 = (SELECT MIN(a.Endorsements) FROM (SELECT TOP 5 * FROM [MyAdventureGame].dbo.Users WHERE [MyAdventureGame].dbo.Users.[Sect] = 'Marauder' ORDER BY [MyAdventureGame].dbo.Users.[Endorsements] DESC) a)
SET @REQUIRED_MARAUDER1 = (SELECT MIN(a.Endorsements) FROM (SELECT TOP 1 * FROM [MyAdventureGame].dbo.Users WHERE [MyAdventureGame].dbo.Users.[Sect] = 'Marauder' ORDER BY [MyAdventureGame].dbo.Users.[Endorsements] DESC) a)
SET @REQUIRED_SAGE5 = (SELECT MIN(a.Endorsements) FROM (SELECT TOP 5 * FROM [MyAdventureGame].dbo.Users WHERE [MyAdventureGame].dbo.Users.[Sect] = 'Sage' ORDER BY [MyAdventureGame].dbo.Users.[Endorsements] DESC) a)
SET @REQUIRED_SAGE1 = (SELECT MIN(a.Endorsements) FROM (SELECT TOP 1 * FROM [MyAdventureGame].dbo.Users WHERE [MyAdventureGame].dbo.Users.[Sect] = 'Sage' ORDER BY [MyAdventureGame].dbo.Users.[Endorsements] DESC) a)
SET @REQUIRED_ARCHITECT5 = (SELECT MIN(a.Endorsements) FROM (SELECT TOP 5 * FROM [MyAdventureGame].dbo.Users WHERE [MyAdventureGame].dbo.Users.[Sect] = 'Architect' ORDER BY [MyAdventureGame].dbo.Users.[Endorsements] DESC) a)
SET @REQUIRED_ARCHITECT1 = (SELECT MIN(a.Endorsements) FROM (SELECT TOP 1 * FROM [MyAdventureGame].dbo.Users WHERE [MyAdventureGame].dbo.Users.[Sect] = 'Architect' ORDER BY [MyAdventureGame].dbo.Users.[Endorsements] DESC) a)
SET @REQUIRED_WARDEN5 = (SELECT MIN(a.Endorsements) FROM (SELECT TOP 5 * FROM [MyAdventureGame].dbo.Users WHERE [MyAdventureGame].dbo.Users.[Sect] = 'Warden' ORDER BY [MyAdventureGame].dbo.Users.[Endorsements] DESC) a)
SET @REQUIRED_WARDEN1 = (SELECT MIN(a.Endorsements) FROM (SELECT TOP 1 * FROM [MyAdventureGame].dbo.Users WHERE [MyAdventureGame].dbo.Users.[Sect] = 'Warden' ORDER BY [MyAdventureGame].dbo.Users.[Endorsements] DESC) a)

UPDATE [MyAdventureGame].dbo.Users
SET [Sect Prefix] = 'Notorious ' WHERE [Sect] = 'Marauder' AND [Endorsements] >= @REQUIRED_MARAUDER5 AND [Endorsements] > 0

UPDATE [MyAdventureGame].dbo.Users
SET [Sect Prefix] = 'Immortal ' WHERE [Sect] = 'Marauder' AND [Endorsements] >= @REQUIRED_MARAUDER1 AND [Endorsements] > 0

UPDATE [MyAdventureGame].dbo.Users
SET [Sect Prefix] = 'Lauded ' WHERE [Sect] = 'Sage' AND [Endorsements] >= @REQUIRED_SAGE5 AND [Endorsements] > 0

UPDATE [MyAdventureGame].dbo.Users
SET [Sect Prefix] = 'Ordained ' WHERE [Sect] = 'Sage' AND [Endorsements] >= @REQUIRED_SAGE1 AND [Endorsements] > 0

UPDATE [MyAdventureGame].dbo.Users
SET [Sect Prefix] = 'Esteemed ' WHERE [Sect] = 'Architect' AND [Endorsements] >= @REQUIRED_ARCHITECT5 AND [Endorsements] > 0

UPDATE [MyAdventureGame].dbo.Users
SET [Sect Prefix] = 'Pre-Eminent ' WHERE [Sect] = 'Architect' AND [Endorsements] >= @REQUIRED_ARCHITECT1 AND [Endorsements] > 0

UPDATE [MyAdventureGame].dbo.Users
SET [Sect Prefix] = 'Infrangible ' WHERE [Sect] = 'Warden' AND [Endorsements] >= @REQUIRED_WARDEN5 AND [Endorsements] > 0

UPDATE [MyAdventureGame].dbo.Users
SET [Sect Prefix] = 'Sovereign ' WHERE [Sect] = 'Warden' AND [Endorsements] >= @REQUIRED_WARDEN1 AND [Endorsements] > 0

/*******************************************************************************
 * CHARTS
 *******************************************************************************/
 DECLARE @MEAN_RATING DECIMAL(3,2)
  DECLARE @MINIMUM_RATINGS int
 SET @MINIMUM_RATINGS = 50
 SET @MEAN_RATING = (SELECT AVG([MyAdventureGame].dbo.[Game Ratings - Calculated].[Calculated Rating]) FROM [MyAdventureGame].dbo.[Game Ratings - Calculated] WHERE [MyAdventureGame].dbo.[Game Ratings - Calculated].[Rating Count] >= @MINIMUM_RATINGS)

 UPDATE [MyAdventureGame].dbo.[Game Ratings - Calculated]
 SET [Pop_Adjusted_Rating] = (((CAST([Rating Count] AS DECIMAL) / ([Rating Count] + @MINIMUM_RATINGS)) * [Calculated Rating]) + ((@MINIMUM_RATINGS / (CAST([Rating Count] AS DECIMAL) + @MINIMUM_RATINGS)) * @MEAN_RATING))
 WHERE [Rating Count] >= @MINIMUM_RATINGS

 UPDATE [MyAdventureGame].dbo.[Game Ratings - Calculated]
 SET [Pop_Adjusted_Rating] = 0
 WHERE [Rating Count] < @MINIMUM_RATINGS

DECLARE @RANKED_STORIES TABLE
(
	[Game Id2] int,
	[Pop_Adjusted_Rating2] DECIMAL(3,2),
	[Year_Published2] int
)

INSERT INTO @RANKED_STORIES ([Game Id2], [Pop_Adjusted_Rating2], Year_Published2)
SELECT [Game ID], [Pop_Adjusted_Rating], Year_Published
FROM [MyAdventureGame].dbo.[Game Ratings - Calculated]
WHERE [MyAdventureGame].dbo.[Game Ratings - Calculated].[Pop_Adjusted_Rating] > 0 
      AND EXISTS(SELECT TOP 1 * FROM MyAdventureGame.dbo.[Games - Published] WHERE MyAdventureGame.dbo.[Games - Published].[Game Id] = [MyAdventureGame].dbo.[Game Ratings - Calculated].[Game ID])

UPDATE [MyAdventureGame].dbo.[Game Ratings - Calculated]
SET [MyAdventureGame].dbo.[Game Ratings - Calculated].[Ranking_Overall] = 0, [MyAdventureGame].dbo.[Game Ratings - Calculated].[Ranking_Year] = 0

UPDATE [MyAdventureGame].dbo.[Game Ratings - Calculated]
SET [MyAdventureGame].dbo.[Game Ratings - Calculated].[Ranking_Overall] = (SELECT COUNT(*) FROM @RANKED_STORIES WHERE [Pop_Adjusted_Rating2] > [MyAdventureGame].dbo.[Game Ratings - Calculated].[Pop_Adjusted_Rating]) + 1
WHERE [MyAdventureGame].dbo.[Game Ratings - Calculated].[Pop_Adjusted_Rating] > 0 
      AND EXISTS(SELECT TOP 1 * FROM MyAdventureGame.dbo.[Games - Published] WHERE MyAdventureGame.dbo.[Games - Published].[Game Id] = [MyAdventureGame].dbo.[Game Ratings - Calculated].[Game ID])

UPDATE [MyAdventureGame].dbo.[Game Ratings - Calculated]
SET [MyAdventureGame].dbo.[Game Ratings - Calculated].[Ranking_Year] = (SELECT COUNT(*) FROM @RANKED_STORIES WHERE [Pop_Adjusted_Rating2] > [MyAdventureGame].dbo.[Game Ratings - Calculated].[Pop_Adjusted_Rating] AND 
                                                                         [Year_Published2] = [MyAdventureGame].dbo.[Game Ratings - Calculated].[Year_Published]) + 1
WHERE [MyAdventureGame].dbo.[Game Ratings - Calculated].[Pop_Adjusted_Rating] > 0 
     AND EXISTS(SELECT TOP 1 * FROM MyAdventureGame.dbo.[Games - Published] WHERE MyAdventureGame.dbo.[Games - Published].[Game Id] = [MyAdventureGame].dbo.[Game Ratings - Calculated].[Game ID])


COMMIT

END

GO

GRANT  EXECUTE  ON [dbo].[Stories_Get_Top_Rated_Stories]  TO [CYS_UserRole]
GO


