USE ChooseYourStory
GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[User_GetProfile]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[User_GetProfile]
GO

CREATE  PROCEDURE [User_GetProfile]
(
  @Username CYSUSERNAME
) AS BEGIN

/****************************************
 * General Info
 ****************************************/
	SELECT [Username],
	       [Avatar_Image_Id] = [Avatar Image ID], 
	       [Point_Total] = [Point Total], 
	       [Endorsements],
	       [Joined_Date] = [Joined Date],  
	       [Story_Count] = 
	           (SELECT COUNT(*) 
			      FROM [MyAdventureGame].dbo.[Games - Published] _GP
				       LEFT JOIN [MyAdventureGame].dbo.[Game Coauthors] _CO
					          ON _GP.[Game Id] = _CO.[Game Id]
					         AND _CO.[Username] = [Users].[Username]
							 AND _CO.[Active Indicator] = 'Y'
    	         WHERE COALESCE(_CO.[Username], _GP.[Username]) = [Users].[Username]), 
	       [Post_Count] = (SELECT COUNT(*) FROM [MyAdventureGame].dbo.[Forums_Posts] FP
		                     JOIN [MyAdventureGame]..[Forums_Messages] FM 
							   ON FP.[Message_Id] = FM.[Message_Id]
		                    WHERE FP.[Username] = [Users].[Username]
							  AND FM.[Forum_Id] <> 11),							   
	       [Won_Duel_Count] =  
	           (SELECT COUNT(*) FROM [MyAdventureGame].dbo.[Duels]  
	             WHERE ([Challenger Username] = [Username] AND [Winner] = 'Challenger')  
	                OR ([Challengee Username] = [Username] AND [Winner] = 'Challengee')),  
	       [Lost_Duel_Count] =  
	           (SELECT COUNT(*) FROM [MyAdventureGame].dbo.[Duels]  
			         WHERE ([Challenger Username] = [Username] AND [Winner] = 'Challengee')  
				          OR ([Challengee Username] = [Username] AND [Winner] = 'Challenger')),  
	       [DuelsEnabled_Indicator] = [Duel Indicator],
	       [Profile_Text] = [Profile],
	       [Sect] = [Sect],
	       [Sect_Prefix] = [Sect Prefix],
	       [Sect_Postfix] = [Sect Postfix],
		   [Is_Banned] = [Banned Indicator],
	       [LastLogon_Date]
 	  FROM [MyAdventureGame].dbo.[Users] [Users]  
	 WHERE [Username] = @UserName

/****************************************
 * Trophies
 ****************************************/
	SELECT T.[Trophy_Name], UT.[Trophy_Notes], T.[Image_Name]
	  FROM [User_Trophies] UT
	       INNER JOIN [User_TrophyTypes] T
	               ON UT.[Trophy_Name] = T.[Trophy_Name]
	 WHERE UT.[Username] = @Username
	 ORDER BY CASE 
	         WHEN T.[Trophy_Name]='100 Points' THEN '00100 Points'
					 WHEN T.[Trophy_Name]='500 Points' THEN '00500 Points'
					 WHEN T.[Trophy_Name]='1000 Points' THEN '01000 Points'
	         WHEN T.[Owner_Username] IS NOT NULL THEN 'Z' + T.[Owner_Username]
					 ELSE T.[Trophy_Name] END



/****************************************
 * Stories
 ****************************************/
	SELECT [Story_Id] = [Games].[Game Id], 
	       [Story_Title] = [Title],
	       [Published_Indicator] =
	         CASE WHEN [Date Published] IS NULL THEN 'N' ELSE 'Y' END,
	       [Coauthor_Indicator] = 
	         CASE WHEN [Coauth].[Game Id] IS NULL THEN 'N' ELSE 'Y' END,
         [Featured_Indicator] =
	         CASE WHEN [Date Category Featured]  IS NULL THEN 'N' ELSE 'Y' END,
	       [Story_Description] = [Description]
	  FROM [MyAdventureGame].dbo.[Games] [Games]
         LEFT JOIN [MyAdventureGame].dbo.[Game Coauthors] [Coauth]
	              ON [Games].[Game Id] = [Coauth].[Game Id]
	             AND [Coauth].[Active Indicator] = 'Y'
	             AND [Coauth].[Username] = @Username
	 WHERE ([Games].[Username] = @Username OR
	        [Coauth].[Username] = @Username)
     AND ([Date Published] IS NOT NULL OR
          [AllowPreview_Indicator] = 'Y')
	 ORDER BY CASE WHEN [Date Published] IS NULL THEN 2 ELSE 1 END, [Title]


/****************************************
 * Articles
 ****************************************/
	SELECT [Article_Id] = [Article Id],
	       [Article_Title] = [Title],
	       [Article_Description] = [Abstract]
	  FROM [MyAdventureGame].dbo.Articles
	 WHERE [Username] = @Username
	   AND [Status] = 'Accepted'
	 ORDER BY [Title]

/****************************************
 * Posts
 ****************************************/
	SELECT TOP 10
	       P.[Message_Id],
	       P.[Post_Date],
		   P.[Post_Id],
	       [Post_Title] = P.[Subject],
	       [Body_Text] = P.[Body],
		   M.[Forum_Id]
	  FROM [MyAdventureGame].dbo.[Forums_Posts] P
      JOIN [MyAdventureGame].[dbo].[Forums_Messages] M
        ON P.[Message_Id] = M.[Message_Id]
	 WHERE P.[Username] = @Username
       AND M.[Forum_Id] <> 10
	 ORDER BY [Post_Date] DESC

END

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

GRANT  EXECUTE  ON [dbo].[User_GetProfile]  TO [CYS_UserRole]
GO

